.. tich_me documentation master file, created by
   sphinx-quickstart on Sat Dec 12 21:08:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tich_me's documentation!
===========================================================

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

